@@ -1,12 +1,12 @@
 import hashlib
 import json
 from pathlib import Path
-import sys
 
 import appdirs
-
-from .pretty import print_info
-
+from rich.console import Console
+from rich.markdown import Markdown
+from rich.panel import Panel
+from rich.style import Style
 
 _printed_announcement = False
 
@@ -16,6 +16,7 @@ def announce(msg: str, only_once: bool = True) -> None:
     if only_once and _printed_announcement:
         return
     local_state_path = Path(appdirs.user_state_dir('backend.ai', 'Lablup'))
+    local_state_path.mkdir(parents=True, exist_ok=True)
     try:
         with open(local_state_path / 'announcement.json', 'rb') as f_current:
             last_state = json.load(f_current)
@@ -27,10 +28,16 @@ def announce(msg: str, only_once: bool = True) -> None:
     msg_hash = hasher.hexdigest()
 
     if not (last_state['hash'] == msg_hash and last_state['dismissed']):
-        print_info("The server has an announcement!", file=sys.stderr)
-        print('----------', file=sys.stderr)
-        print(msg, file=sys.stderr)
-        print('----------', file=sys.stderr)
+        console = Console(stderr=True)
+        doc = Markdown(msg)
+        console.print(
+            Panel(
+                doc,
+                title="Server Announcement",
+                border_style=Style(color='cyan', bold=True),
+                width=min(console.size.width, 82),
+            ),
+        )
     _printed_announcement = True
 
     last_state['hash'] = msg_hash
