@@ -531,6 +531,7 @@ def upload(session_id, files):
     FILES: One or more paths to upload.
     """
     if len(files) < 1:
+        print_warn("Please specify one or more file paths after session ID or name.")
         return
     with Session() as session:
         try:
@@ -563,6 +564,7 @@ def download(session_id, files, dest):
     FILES: One or more paths inside compute session.
     """
     if len(files) < 1:
+        print_warn("Please specify one or more file paths after session ID or name.")
         return
     with Session() as session:
         try:
@@ -637,6 +639,28 @@ def logs(session_id):
             sys.exit(1)
 
 
+@session.command()
+@click.argument('session_id', metavar='SESSID')
+@click.argument('new_id', metavar='NEWID')
+def rename(session_id, new_id):
+    '''
+    Renames session name of running session.
+
+    \b
+    SESSID: Session ID or its alias given when creating the session.
+    NEWID: New Session ID to rename to.
+    '''
+
+    with Session() as session:
+        try:
+            kernel = session.ComputeSession(session_id)
+            kernel.rename(new_id)
+            print_done(f'Session renamed to {new_id}.')
+        except Exception as e:
+            print_error(e)
+            sys.exit(1)
+
+
 def _ssh_cmd(docs: str = None):
 
     @click.argument("session_ref",  type=str, metavar='SESSION_REF')
@@ -657,6 +681,8 @@ def _ssh_cmd(docs: str = None):
                     [
                         "ssh",
                         "-o", "StrictHostKeyChecking=no",
+                        "-o", "UserKnownHostsFile=/dev/null",
+                        "-o", "NoHostAuthenticationForLocalhost=yes",
                         "-i", key_path,
                         "work@localhost",
                         "-p", str(port),
@@ -741,6 +767,8 @@ def _scp_cmd(docs: str = None):
                     [
                         "scp",
                         "-o", "StrictHostKeyChecking=no",
+                        "-o", "UserKnownHostsFile=/dev/null",
+                        "-o", "NoHostAuthenticationForLocalhost=yes",
                         "-i", key_path,
                         "-P", str(port),
                         *recursive_args,
