@@ -276,15 +276,17 @@ class ComputeSession(BaseFunction):
         else:
             params['config']['clusterSize'] = cluster_size
         if api_session.get().api_version >= (5, '20191215'):
-            params['config'].update({
-                'mount_map': mount_map,
-                'preopen_ports': preopen_ports,
-                'agentList': assign_agent,
-            })
-            params.update({
-                'starts_at': starts_at,
-                'bootstrap_script': bootstrap_script,
-            })
+            if assign_agent is not None:
+                params['config'].update({
+                    'mount_map': mount_map,
+                    'preopen_ports': preopen_ports,
+                    'agentList': assign_agent,
+                })
+            else:
+                params['config'].update({
+                    'mount_map': mount_map,
+                    'preopen_ports': preopen_ports,
+                })
         if api_session.get().api_version >= (4, '20190615'):
             params.update({
                 'owner_access_key': owner_access_key,
@@ -529,6 +531,22 @@ class ComputeSession(BaseFunction):
         async with rqst.fetch():
             pass
 
+    @api_function
+    async def rename(self, new_id):
+        """
+        Renames Session ID of running compute session.
+        """
+        params = {'name': new_id}
+        if self.owner_access_key:
+            params['owner_access_key'] = self.owner_access_key
+        prefix = get_naming(api_session.get().api_version, 'path')
+        rqst = Request(
+            'POST', f'/{prefix}/{self.name}/rename',
+            params=params,
+        )
+        async with rqst.fetch():
+            pass
+
     @api_function
     async def interrupt(self):
         """
